@@ -380,11 +380,7 @@ private:
                 }
             } while (!statusLine.isNull() && uidLine.isNull());
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
             uidStrings << uidLine.split(QLatin1Char('\t'), Qt::SkipEmptyParts);
-#else
-            uidStrings << uidLine.split(QLatin1Char('\t'), QString::SkipEmptyParts);
-#endif
             // Must be 5 entries: 'Uid: %d %d %d %d' and
             // uid string must be less than 5 chars (uint)
             if (uidStrings.size() == 5) {
