@@ -16,12 +16,9 @@ HistoryScroll::HistoryScroll(HistoryType *t) :
 {
 }
 
-HistoryScroll::~HistoryScroll()
-{
-    delete _historyType;
-}
+HistoryScroll::~HistoryScroll() = default;
 
-bool HistoryScroll::hasScroll()
+bool HistoryScroll::hasScroll() const
 {
     return true;
 }
